@@ -54,7 +54,7 @@ class FVMProvider(ReboticsBaseProvider):
         return self.session.post(pk=pk)
 
     @remote_service('/api/previews/{barcode}/')
-    def get_preview_permalink(self,  barcode):
+    def get_preview_permalink(self, barcode):
         assert barcode.isdigit()
         url = self.build_url(self.session.url.format(barcode=barcode))
         token = self.generate_token(url)
@@ -67,9 +67,34 @@ class FVMProvider(ReboticsBaseProvider):
         # Token will contain numbers, letters and symbols
 
         if self.secret_key is None or self.codename is None:
-            raise AttributeError("Identifiers for token generation are not present. Set secret_key and codename attributes or call .set_retailer_identifier method")
+            raise AttributeError(
+                "Identifiers for token generation are not present. Set secret_key and codename attributes or call .set_retailer_identifier method")
         lhmac = hmac.new(self.secret_key.encode('utf-8'), digestmod=sha256)
         string_to_sign = f'{self.codename}/{path}'
         lhmac.update(string_to_sign.encode('utf-8'))
         b64 = base64.urlsafe_b64encode(lhmac.digest())
         return b64
+
+    @remote_service('/api/previews/')
+    def upload_preview(self, barcode, image_url):
+        return self.session.post(json={
+            'barcode': barcode,
+            'image_url': image_url
+        })
+
+    @remote_service('/api/products/')
+    def create_product(self, code, title):
+        return self.session.post(json={
+            'code': code,
+            'title': title,
+        })
+
+    @remote_service('/api/products/{id}/')
+    def update_product(self, id_, code, title):
+        return self.session.put(
+            id=id_,
+            json={
+                'code': code,
+                'title': title,
+            }
+        )
